@@ -1,7 +1,8 @@
 #
 #	Cclient.pm
+#       Last Edited: Mon Sep 20 15:39:59 WEST 2004
 #
-#	Copyright (c) 1998,1999,2000,2001 Malcolm Beattie
+#	Copyright (c) 1998 - 2004 Malcolm Beattie
 #
 #	You may distribute under the terms of either the GNU General Public
 #	License or the Artistic License, as specified in the README file.
@@ -13,11 +14,11 @@ use Exporter;
 use strict;
 use vars qw($VERSION @ISA @EXPORT_OK %_callback);
 
-$VERSION = "1.4.1";
+$VERSION = "1.10";
 @ISA = qw(Exporter DynaLoader);
-@EXPORT_OK = qw(set_callback get_callback rfc822_base64 rfc822_qprint
-	rfc822_date rfc822_parse_adrlist rfc822_write_address rfc822_output);
-
+@EXPORT_OK = qw(set_callback get_callback rfc822_base64 rfc822_binary
+		rfc822_qprint rfc822_8bit utf8_mime2text rfc822_date
+		rfc822_parse_adrlist rfc822_write_address rfc822_output);
 {
 	package Mail::Cclient::Address;
 	use vars qw(%FIELDS);
@@ -48,10 +49,12 @@ $VERSION = "1.4.1";
 		id          => 5,
 		description => 6,
 		nested      => 7,
-		lines       => 8,
-		bytes       => 9,
-		md5         => 10,
-		disposition => 11);
+		language    => 8,
+		location    => 9,
+		lines       => 10,
+		bytes       => 11,
+		md5         => 12,
+		disposition => 13);
 
 	sub type { shift->[1] }
 	sub encoding { shift->[2] }
@@ -60,10 +63,12 @@ $VERSION = "1.4.1";
 	sub id { shift->[5] }
 	sub description { shift->[6] }
 	sub nested { shift->[7] }
-	sub lines { shift->[8] }
-	sub bytes { shift->[9] }
-	sub md5 { shift->[10] }
-	sub disposition { shift->[11] }
+	sub language { shift->[8] }
+	sub location { shift->[9] }
+	sub lines { shift->[10] }
+	sub bytes { shift->[11] }
+	sub md5 { shift->[12] }
+	sub disposition { shift->[13] }
 }
 
 {
@@ -71,7 +76,7 @@ $VERSION = "1.4.1";
 	use vars qw(%FIELDS);
 
 	%FIELDS = (
-		remail => 1,
+		remail      => 1,
 		return_path => 2,
 		date        => 3,
 		from        => 4,
@@ -112,12 +117,14 @@ $VERSION = "1.4.1";
 		msgno       => 1,
 		date        => 2,
 		flags       => 3,
-		rfc822_size => 4);
+		rfc822_size => 4,
+		imapdate    => 5);
 
 	sub msgno { shift->[1] }
 	sub date { shift->[2] }
 	sub flags { shift->[3] }
 	sub rfc822_size { shift->[4] }
+	sub imapdate { shift->[5] }
 }
 
 # Our own methods
@@ -161,7 +168,7 @@ sub parameters {
 
 sub Mail::Cclient::SMTP::new {
 	my $class = shift;
-	return Mail::Cclient::SMTP::open(undef, @_);
+	return Mail::Cclient::SMTP::open_full("Mail::Cclient::SMTP", @_);
 }
 
 bootstrap Mail::Cclient;
